
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/Toggle.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvFont.h>
#include <X11/xv/xvBasicBitmap.h>
#include <X11/xv/xvToggle.h>

// ------------------------------------------

xvToggle::xvToggle()
{	
	alloc=FALSE;
}

// ------------------------------------------

xvToggle::xvToggle(String name, xvCore & parent, XtCallbackProc callback,
				String radiodata)
{
	init(name, parent, callback, radiodata);
}

// ------------------------------------------

xvToggle::~xvToggle()
{
	if (alloc) XtDestroyWidget(w);
}

// ------------------------------------------

void xvToggle::init(String name, xvCore & parent, XtCallbackProc callback, 
			String radiodata)
{
	String rdata=name;
	if (radiodata!=NULL)
		rdata=radiodata;

	w=XtVaCreateManagedWidget(name, toggleWidgetClass, parent.ID(),
		"radioData", (XtPointer) rdata,
		NULL);

	XtAddCallback(w, XtNcallback, callback, 0);
	alloc=TRUE;

	bfont.init(w, NULL);

}

// ------------------------------------------

void xvToggle::ChangeFont(String fontname)
{
	if (fontname != NULL) {
		bfont.FLoadFont(fontname);
		XtVaSetValues(w, XtNfont, (XtArgVal) bfont.FontRef(), NULL);
	}
}

// -----------------------------------------------------------------

int xvToggle::ChangeBitmap(String name, int pixtype, int position)
{
	int err;

	if ((err=bmap.ReadFile(name, pixtype)) == 0)
		if (position==XVCENTREBITMAP)
			XtVaSetValues(w, XtNbitmap, (XtArgVal) bmap.GetPixmap(), NULL);
		else
			XtVaSetValues(w, XtNleftBitmap, (XtArgVal) bmap.GetPixmap(), NULL);
	return(err);
}

// -----------------------------------------------------------------


Boolean xvToggle::GetState()
{
	Boolean statex;

	XtVaGetValues(w, XtNstate, &statex, NULL);

	return(statex);
}

// -------------------------------------------

void xvToggle::ChangeGroup(xvCore & group)
{
	XawToggleChangeRadioGroup(w, group.ID());
}

// -------------------------------------------

void xvToggle::ChangeCurrent(String rdata)
{
	XawToggleSetCurrent(w, rdata);
}

// -------------------------------------------

void xvToggle::UnSetGroup()
{
	XawToggleUnsetCurrent(w);
}

// -------------------------------------------

XtPointer xvToggle::GetCurrent()
{
	return(XawToggleGetCurrent(w));
}

// -------------------------------------------

void xvToggle::On()
{
	XtVaSetValues(w, XtNstate, TRUE, NULL);
}

// -------------------------------------------

void xvToggle::Off()
{
	XtVaSetValues(w, XtNstate, FALSE, NULL);
}

// -------------------------------------------

void xvToggle::State(Boolean statex)
{
	XtVaSetValues(w, XtNstate, statex, NULL);
}

// -------------------------------------------
	